Merge "Update language to comply with Android's inclusive language guidance" into main am: 5908abd413 am: 168ac70192 am: 5eed0177d1 am: f8abcc794c
Original change: https://android-review.googlesource.com/c/platform/frameworks/base/+/2717544
Change-Id: Id24660f4486e9f22d35e924f9c36d2299c633087
Signed-off-by: Automerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>
diff --git a/apct-tests/perftests/autofill/src/android/view/autofill/LoginTest.java b/apct-tests/perftests/autofill/src/android/view/autofill/LoginTest.java
index a5d1e00..59f08f6 100644
--- a/apct-tests/perftests/autofill/src/android/view/autofill/LoginTest.java
+++ b/apct-tests/perftests/autofill/src/android/view/autofill/LoginTest.java
@@ -140,7 +140,7 @@
state.resumeTiming();
}
- // Sanity check
+ // Check for no errors
callback.assertNoAsyncErrors();
} finally {
mAfm.unregisterCallback(callback);
@@ -190,7 +190,7 @@
state.resumeTiming();
}
- // Sanity check
+ // Check for no errors
callback.assertNoAsyncErrors();
} finally {
mAfm.unregisterCallback(callback);
@@ -303,7 +303,7 @@
callback.expectEvent(mPassword, EVENT_INPUT_SHOWN);
}
- // Sanity check
+ // Check for no errors
callback.assertNoAsyncErrors();
} finally {
mAfm.unregisterCallback(callback);
diff --git a/apct-tests/perftests/windowmanager/src/android/wm/RelayoutPerfTest.java b/apct-tests/perftests/windowmanager/src/android/wm/RelayoutPerfTest.java
index b0da7d1..c42c7ca 100644
--- a/apct-tests/perftests/windowmanager/src/android/wm/RelayoutPerfTest.java
+++ b/apct-tests/perftests/windowmanager/src/android/wm/RelayoutPerfTest.java
@@ -111,7 +111,7 @@
stopProfiling();
}
- /** A dummy view to get IWindow. */
+ /** A placeholder view to get IWindow. */
private static class ContentView extends LinearLayout {
ContentView(Context context) {
super(context);
diff --git a/apct-tests/perftests/multiuser/src/android/multiuser/UserLifecycleTests.java b/apct-tests/perftests/multiuser/src/android/multiuser/UserLifecycleTests.java
index 6dba5b3..a2c67bc 100644
--- a/apct-tests/perftests/multiuser/src/android/multiuser/UserLifecycleTests.java
+++ b/apct-tests/perftests/multiuser/src/android/multiuser/UserLifecycleTests.java
@@ -104,16 +104,16 @@
/** Name of users/profiles in the test. Users with this name may be freely removed. */
private static final String TEST_USER_NAME = "UserLifecycleTests_test_user";
- /** Name of dummy package used when timing how long app launches take. */
+ /** Name of placeholder package used when timing how long app launches take. */
private static final String DUMMY_PACKAGE_NAME = "perftests.multiuser.apps.dummyapp";
- // Copy of UserSystemPackageInstaller whitelist mode constants.
- private static final String PACKAGE_WHITELIST_MODE_PROP =
+ // Copy of UserSystemPackageInstaller allowlist mode constants.
+ private static final String PACKAGE_ALLOWLIST_MODE_PROP =
"persist.debug.user.package_whitelist_mode";
- private static final int USER_TYPE_PACKAGE_WHITELIST_MODE_DISABLE = 0;
- private static final int USER_TYPE_PACKAGE_WHITELIST_MODE_ENFORCE = 0b001;
- private static final int USER_TYPE_PACKAGE_WHITELIST_MODE_IMPLICIT_WHITELIST = 0b100;
- private static final int USER_TYPE_PACKAGE_WHITELIST_MODE_DEVICE_DEFAULT = -1;
+ private static final int USER_TYPE_PACKAGE_ALLOWLIST_MODE_DISABLE = 0;
+ private static final int USER_TYPE_PACKAGE_ALLOWLIST_MODE_ENFORCE = 0b001;
+ private static final int USER_TYPE_PACKAGE_ALLOWLIST_MODE_IMPLICIT_ALLOWLIST = 0b100;
+ private static final int USER_TYPE_PACKAGE_ALLOWLIST_MODE_DEVICE_DEFAULT = -1;
private UserManager mUm;
private ActivityManager mAm;
@@ -1178,13 +1178,13 @@
}
// TODO: This is just a POC. Do this properly and add more.
/** Tests starting (unlocking) a newly-created profile using the user-type-pkg-whitelist. */
@Test(timeout = TIMEOUT_MAX_TEST_TIME_MS)
public void managedProfileUnlock_usingWhitelist() throws RemoteException {
assumeTrue(mHasManagedUserFeature);
- final int origMode = getUserTypePackageWhitelistMode();
- setUserTypePackageWhitelistMode(USER_TYPE_PACKAGE_WHITELIST_MODE_ENFORCE
- | USER_TYPE_PACKAGE_WHITELIST_MODE_IMPLICIT_WHITELIST);
+ final int origMode = getUserTypePackageAllowlistMode();
+ setUserTypePackageAllowlistMode(USER_TYPE_PACKAGE_ALLOWLIST_MODE_ENFORCE
+ | USER_TYPE_PACKAGE_ALLOWLIST_MODE_IMPLICIT_ALLOWLIST);
try {
while (mRunner.keepRunning()) {
@@ -1201,15 +1201,15 @@
mRunner.resumeTimingForNextIteration();
}
} finally {
- setUserTypePackageWhitelistMode(origMode);
+ setUserTypePackageAllowlistMode(origMode);
}
}
/** Tests starting (unlocking) a newly-created profile NOT using the user-type-pkg-whitelist. */
@Test(timeout = TIMEOUT_MAX_TEST_TIME_MS)
public void managedProfileUnlock_notUsingWhitelist() throws RemoteException {
assumeTrue(mHasManagedUserFeature);
- final int origMode = getUserTypePackageWhitelistMode();
- setUserTypePackageWhitelistMode(USER_TYPE_PACKAGE_WHITELIST_MODE_DISABLE);
+ final int origMode = getUserTypePackageAllowlistMode();
+ setUserTypePackageAllowlistMode(USER_TYPE_PACKAGE_ALLOWLIST_MODE_DISABLE);
try {
while (mRunner.keepRunning()) {
@@ -1226,7 +1226,7 @@
mRunner.resumeTimingForNextIteration();
}
} finally {
- setUserTypePackageWhitelistMode(origMode);
+ setUserTypePackageAllowlistMode(origMode);
}
}
@@ -1456,17 +1456,17 @@
attestTrue(errMsg, success);
}
- /** Gets the PACKAGE_WHITELIST_MODE_PROP System Property. */
- private int getUserTypePackageWhitelistMode() {
- return SystemProperties.getInt(PACKAGE_WHITELIST_MODE_PROP,
- USER_TYPE_PACKAGE_WHITELIST_MODE_DEVICE_DEFAULT);
+ /** Gets the PACKAGE_ALLOWLIST_MODE_PROP System Property. */
+ private int getUserTypePackageAllowlistMode() {
+ return SystemProperties.getInt(PACKAGE_ALLOWLIST_MODE_PROP,
+ USER_TYPE_PACKAGE_ALLOWLIST_MODE_DEVICE_DEFAULT);
}
- /** Sets the PACKAGE_WHITELIST_MODE_PROP System Property to the given value. */
- private void setUserTypePackageWhitelistMode(int mode) {
+ /** Sets the PACKAGE_ALLOWLIST_MODE_PROP System Property to the given value. */
+ private void setUserTypePackageAllowlistMode(int mode) {
String result = ShellHelper.runShellCommand(
- String.format("setprop %s %d", PACKAGE_WHITELIST_MODE_PROP, mode));
- attestFalse("Failed to set sysprop " + PACKAGE_WHITELIST_MODE_PROP + ": " + result,
+ String.format("setprop %s %d", PACKAGE_ALLOWLIST_MODE_PROP, mode));
+ attestFalse("Failed to set sysprop " + PACKAGE_ALLOWLIST_MODE_PROP + ": " + result,
result != null && result.contains("Failed"));
}
@@ -1178,13 +1178,13 @@
}
// TODO: This is just a POC. Do this properly and add more.
- /** Tests starting (unlocking) a newly-created profile using the user-type-pkg-whitelist. */
+ /** Tests starting (unlocking) a newly-created profile using the user-type-pkg-allowlist. */
public void managedProfileUnlock_usingWhitelist() throws RemoteException {
@@ -1201,15 +1201,15 @@
}
}
- /** Tests starting (unlocking) a newly-created profile NOT using the user-type-pkg-whitelist. */
+ /** Tests starting (unlocking) a newly-created profile NOT using the user-type-pkg-allowlist. */
public void managedProfileUnlock_notUsingWhitelist() throws RemoteException {